==> net.bluemind.p2.platform-4.9.3879.zip: BM/MailboxMgmtClient.js <==
/**
 * BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

/**
 * RPC Client
 */
MailboxMgmtClient._rpcClient;

/**
 * URL
 */
MailboxMgmtClient._baseUrl;

/**
 * @type {string} domainUid
 * @private
 */
MailboxMgmtClient.prototype._domainUid;

/**
 * @constructor
 */ 
function MailboxMgmtClient(base, sid , domainUid ) {
  this._rpcClient = Components.classes["@blue-mind.net/rpcclient;1"].getService().wrappedJSObject;
  this._rpcClient.setAuthKey(sid ? sid : null);
  this._baseUrl = base + '/api/mgmt/mailbox/{domainUid}';
  
  this._domainUid = domainUid;
  this._baseUrl = this._baseUrl.replace('{domainUid}',domainUid);
};

MailboxMgmtClient.prototype.setAuthKey = function(sid) {
    this._rpcClient.setAuthKey(sid);
};

/*
 *
 */
MailboxMgmtClient.prototype.getLiteStats = function() {
  let url = this._baseUrl + "/liteStats";


  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "GET", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.getShardsStats = function() {
  let url = this._baseUrl + "/shardsStats";


  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "GET", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.consolidateMailbox = function( mailboxUid  ) {
  let url = this._baseUrl + "/{mailboxUid}/_consolidate";

  url = url.replace("{mailboxUid}", mailboxUid);

  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "POST", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.consolidateDomain = function() {
  let url = this._baseUrl + "/_consolidate";


  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "POST", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.moveIndex = function( mailboxUid ,  index ,  deleteSource  ) {
  let url = this._baseUrl + "/{mailboxUid}/_move_index";

  url = url.replace("{mailboxUid}", mailboxUid);

  url += "?index=" + encodeURIComponent(index);
  url += "&deleteSource=" + encodeURIComponent(deleteSource);
  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "POST", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.resetMailbox = function( mailboxUid  ) {
  let url = this._baseUrl + "/{mailboxUid}/_reset";

  url = url.replace("{mailboxUid}", mailboxUid);

  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "POST", responseType);
  let body = null;
  return this._execute(cmd, body);
};

MailboxMgmtClient.prototype._execute = function(cmd, data) {
  cmd.getData = function() {
    if (data != null){
      return JSON.stringify(data);
    } 
    return null;
  };

  cmd.onSuccess = function(xhr) {
    let contentType = xhr.getResponseHeader("content-type");
    if (contentType == "application/json" && xhr.responseText) {
      cmd.resolve(JSON.parse(xhr.responseText));
    } else {
      cmd.resolve(xhr.response);
    }
  };

  cmd.onFailure = function(xhr) {
    let resp = xhr.response;
    if (resp != null) {
        cmd.reject(resp);
    } else {
        cmd.reject(xhr.status);
    }
  };

  let self = this;
  let result = new Promise(function(resolve, reject) {
    try {
      cmd.resolve = resolve;
      cmd.reject = reject;
      self._rpcClient.execute(cmd);
    } catch(e) {
      reject(e);
    }
  });
  return result;
}

==> net.bluemind.p2.platform-5.4.2696.zip: BM/MailboxMgmtClient.js <==
/**
 * BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

/**
 * RPC Client
 */
MailboxMgmtClient._rpcClient;

/**
 * URL
 */
MailboxMgmtClient._baseUrl;

/**
 * @type {string} domainUid
 * @private
 */
MailboxMgmtClient.prototype._domainUid;

/**
 * @constructor
 */ 
function MailboxMgmtClient(base, sid , domainUid ) {
  this._rpcClient = Components.classes["@blue-mind.net/rpcclient;1"].getService().wrappedJSObject;
  this._rpcClient.setAuthKey(sid ? sid : null);
  this._baseUrl = base + '/api/mgmt/mailbox/{domainUid}';
  
  this._domainUid = domainUid;
  this._baseUrl = this._baseUrl.replace('{domainUid}',domainUid);
};

MailboxMgmtClient.prototype.setAuthKey = function(sid) {
    this._rpcClient.setAuthKey(sid);
};

/*
 *
 */
MailboxMgmtClient.prototype.addIndexToRing = function( numericIndex  ) {
  let url = this._baseUrl + "/{numericIndex}/_add_index";

  url = url.replace("{numericIndex}", numericIndex);

  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "PUT", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.consolidateDomain = function() {
  let url = this._baseUrl + "/_consolidate";


  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "POST", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.consolidateMailbox = function( mailboxUid  ) {
  let url = this._baseUrl + "/{mailboxUid}/_consolidate";

  url = url.replace("{mailboxUid}", mailboxUid);

  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "POST", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.deleteIndexFromRing = function( numericIndex  ) {
  let url = this._baseUrl + "/{numericIndex}/_remove_index";

  url = url.replace("{numericIndex}", numericIndex);

  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "DELETE", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.getLiteStats = function() {
  let url = this._baseUrl + "/liteStats";


  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "GET", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.getShardsStats = function() {
  let url = this._baseUrl + "/shardsStats";


  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "GET", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.moveIndex = function( mailboxUid ,  index ,  deleteSource  ) {
  let url = this._baseUrl + "/{mailboxUid}/_move_index";

  url = url.replace("{mailboxUid}", mailboxUid);

  url += "?index=" + encodeURIComponent(index);
  url += "&deleteSource=" + encodeURIComponent(deleteSource);
  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "POST", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.resetMailbox = function( mailboxUid  ) {
  let url = this._baseUrl + "/{mailboxUid}/_reset";

  url = url.replace("{mailboxUid}", mailboxUid);

  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "POST", responseType);
  let body = null;
  return this._execute(cmd, body);
};

/*
 *
 */
MailboxMgmtClient.prototype.respawnMailbox = function( mailboxUid  ) {
  let url = this._baseUrl + "/{mailboxUid}/_respawn";

  url = url.replace("{mailboxUid}", mailboxUid);

  let responseType = "";
  let cmd = this._rpcClient.newCommand(url, "POST", responseType);
  let body = null;
  return this._execute(cmd, body);
};

MailboxMgmtClient.prototype._execute = function(cmd, data) {
  cmd.getData = function() {
    if (data != null){
      return JSON.stringify(data);
    } 
    return null;
  };

  cmd.onSuccess = function(xhr) {
    let contentType = xhr.getResponseHeader("content-type");
    if (contentType == "application/json" && xhr.responseText) {
      cmd.resolve(JSON.parse(xhr.responseText));
    } else {
      cmd.resolve(xhr.response);
    }
  };

  cmd.onFailure = function(xhr) {
    let resp = xhr.response;
    if (resp != null) {
        cmd.reject(resp);
    } else {
        cmd.reject(xhr.status);
    }
  };

  let self = this;
  let result = new Promise(function(resolve, reject) {
    try {
      cmd.resolve = resolve;
      cmd.reject = reject;
      self._rpcClient.execute(cmd);
    } catch(e) {
      reject(e);
    }
  });
  return result;
}
